# -*- mode: makefile; coding: utf-8 -*-
# Author: Marc Dequènes (Duck) <mdequenes@proformatique.com>
# Copyright © 2007 Proformatique
#
# Version: 1.1
# Description: a class for building multiple PHP versions
#
# License:
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2, or (at
# your option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
# 02111-1307 USA.
#
# Changelog:
# - 1.1: added module-specific php.ini automatic installation
#        (using debian/php<ver>.ini)
# - 1.0: initial release with automatic multibuild
#

_cdbs_scripts_path ?= /usr/lib/cdbs
_cdbs_rules_path ?= /usr/share/cdbs/1/rules
_cdbs_class_path ?= /usr/share/cdbs/1/class

ifndef _cdbs_class_php_distutils
_cdbs_class_php_distutils = 1

include $(_cdbs_rules_path)/buildcore.mk$(_cdbs_makefile_suffix)
include $(_cdbs_class_path)/langcore.mk$(_cdbs_makefile_suffix)


# adapted from makefile-vars.mk
DEB_MAKE_ENVVARS =
DEB_MAKE_INVOKE = $(DEB_MAKE_ENVVARS) $(MAKE) -C $(DEB_BUILDDIR_PHP)
# do not load makefile class rules
_cdbs_class_makefile = 1
include /usr/share/cdbs/1/class/autotools-vars.mk
# override builddir
DEB_CONFIGURE_INVOKE = cd $(DEB_BUILDDIR_PHP) && $(DEB_CONFIGURE_SCRIPT_ENV) $(DEB_CONFIGURE_SCRIPT) $(DEB_CONFIGURE_NORMAL_ARGS)


DEB_PHP_PACKAGES = $(filter-out php-%, $(filter php%, $(DEB_PACKAGES)))
# avoid --srcdir generation
DEB_BUILDDIR = $(CURDIR)/build
# generate build dirs
DEB_BUILDDIR_PHP = $(CURDIR)/build-$(cdbs_curpkg)

cdbs_php_ver = $(filter-out -%,$(subst -, -,$(patsubst php%,%,$(cdbs_curpkg))))
cdbs_php_ext = $(filter-out %-,$(subst -,- ,$(patsubst php%,%,$(cdbs_curpkg))))


$(patsubst %,makebuilddir/%,$(DEB_PHP_PACKAGES)) ::
	mkdir -p $(DEB_BUILDDIR_PHP)

$(patsubst %,configure/%,$(DEB_PHP_PACKAGES)) ::
	if [ ! -e $(DEB_BUILDDIR_PHP)/config.status ]; then \
		phpize$(cdbs_php_ver); \
		$(DEB_CONFIGURE_INVOKE) $(cdbs_configure_flags) $(DEB_CONFIGURE_EXTRA_FLAGS) $(DEB_CONFIGURE_USER_FLAGS) \
			--with-php-config=php-config$(cdbs_php_ver); \
	fi

$(patsubst %,build/%,$(DEB_PHP_PACKAGES)) ::
	+$(DEB_MAKE_INVOKE)

$(patsubst %,install/%,$(DEB_PHP_PACKAGES)) ::
	+$(DEB_MAKE_INVOKE) install INSTALL_ROOT=$(CURDIR)/debian/$(cdbs_curpkg)
	if [ -e $(CURDIR)/debian/php$(cdbs_php_ver).ini ]; then \
		ZDIR=$(CURDIR)/debian/$(cdbs_curpkg)/etc/php$(cdbs_php_ver)/conf.d/; \
		mkdir -p $$ZDIR; \
		cp $(CURDIR)/debian/php$(cdbs_php_ver).ini $$ZDIR/$(cdbs_php_ext).ini; \
	fi

$(patsubst %,binary-predeb/%,$(DEB_PHP_PACKAGES)) ::
	find debian/$(cdbs_curpkg) -depth \( -name ".cvsignore" -o -name ".arch-ids" \) -exec rm -rf {} \;
	echo "php:Depends=phpapi-`php-config$(cdbs_php_ver) --phpapi`" >> $(CURDIR)/debian/$(cdbs_curpkg).substvars; \

$(patsubst %,cleanbuilddir/%,$(DEB_PHP_PACKAGES)) ::
	-rm -r $(DEB_BUILDDIR_PHP)
	phpize$(cdbs_php_ver) --clean


endif

